@@ -15,17 +15,20 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Dict, List, Union
 
+from supertokens_python.logger import log_debug_message
 from supertokens_python.recipe.emailpassword.constants import (
     FORM_FIELD_EMAIL_ID, FORM_FIELD_PASSWORD_ID)
 from supertokens_python.recipe.emailpassword.interfaces import (
-    APIInterface, CreateResetPasswordWrongUserIdError,
-    EmailExistsGetOkResult, GeneratePasswordResetTokenPostOkResult,
+    APIInterface, CreateResetPasswordWrongUserIdError, EmailExistsGetOkResult,
+    GeneratePasswordResetTokenPostOkResult,
     PasswordResetPostInvalidTokenResponse, PasswordResetPostOkResult,
     ResetPasswordUsingTokenInvalidTokenError, SignInPostOkResult,
     SignInPostWrongCredentialsError, SignInWrongCredentialsError,
-    SignUpEmailAlreadyExistsError,
-    SignUpPostEmailAlreadyExistsError, SignUpPostOkResult)
-from supertokens_python.recipe.emailpassword.types import FormField
+    SignUpEmailAlreadyExistsError, SignUpPostEmailAlreadyExistsError,
+    SignUpPostOkResult)
+from supertokens_python.recipe.emailpassword.types import (
+    FormField, TypeEmailPasswordPasswordResetEmailDeliveryInput,
+    TypeEmailPasswordPasswordResetEmailDeliveryInputUser)
 from supertokens_python.recipe.session.asyncio import create_new_session
 from supertokens_python.utils import find_first_occurrence_in_list
 
@@ -54,16 +57,19 @@ class APIImplementation(APIInterface):
         token_result = await api_options.recipe_implementation.create_reset_password_token(user.user_id, user_context)
 
         if isinstance(token_result, CreateResetPasswordWrongUserIdError):
+            log_debug_message("Password reset email not sent, unknown user id: %s", user.user_id)
             return GeneratePasswordResetTokenPostOkResult()
 
         token = token_result.token
         password_reset_link = await api_options.config.reset_password_using_token_feature.get_reset_password_url(
             user, user_context) + '?token=' + token + '&rid=' + api_options.recipe_id
 
-        try:
-            await api_options.config.reset_password_using_token_feature.create_and_send_custom_email(user, password_reset_link, user_context)
-        except Exception:
-            pass
+        log_debug_message("Sending password reset email to %s", email)
+        send_email_input = TypeEmailPasswordPasswordResetEmailDeliveryInput(
+            user=TypeEmailPasswordPasswordResetEmailDeliveryInputUser(user.user_id, user.email),
+            password_reset_link=password_reset_link
+        )
+        await api_options.email_delivery.ingredient_interface_impl.send_email(send_email_input, user_context)
 
         return GeneratePasswordResetTokenPostOkResult()
 
