@@ -15,7 +15,7 @@ from typing import Any, Dict, Union
 
 from supertokens_python.recipe.emailpassword import EmailPasswordRecipe
 
-from ..types import User
+from ..types import TypeEmailPasswordEmailDeliveryInput, User
 
 
 async def create_email_verification_token(user_id: str, user_context: Union[None, Dict[str, Any]] = None):
@@ -98,3 +98,9 @@ async def revoke_email_verification_token(user_id: str, user_context: Union[None
     email = await EmailPasswordRecipe.get_instance().get_email_for_user_id(user_id, user_context)
     return await EmailPasswordRecipe.get_instance().email_verification_recipe.recipe_implementation.revoke_email_verification_tokens(
         user_id, email, user_context)
+
+
+async def send_email(input_: TypeEmailPasswordEmailDeliveryInput, user_context: Union[None, Dict[str, Any]] = None):
+    if user_context is None:
+        user_context = {}
+    return await EmailPasswordRecipe.get_instance().email_delivery.ingredient_interface_impl.send_email(input_, user_context)
