@@ -14,9 +14,19 @@
 from __future__ import annotations
 
 from os import environ
-from typing import TYPE_CHECKING, Any, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Union, cast
 
+from supertokens_python.ingredients.emaildelivery import \
+    EmailDeliveryIngredient
+from supertokens_python.ingredients.emaildelivery.types import \
+    EmailDeliveryConfig
 from supertokens_python.normalised_url_path import NormalisedURLPath
+from supertokens_python.recipe.emailpassword.types import (
+    EmailPasswordIngredients, TypeEmailPasswordEmailDeliveryInput)
+from supertokens_python.recipe.emailverification.interfaces import \
+    TypeEmailVerificationEmailDeliveryInput
+from supertokens_python.recipe.emailverification.types import \
+    EmailVerificationIngredients
 from supertokens_python.recipe_module import APIHandled, RecipeModule
 
 from ...exceptions import SuperTokensError
@@ -49,26 +59,44 @@ from .utils import (InputEmailVerificationConfig, InputOverrideConfig,
 class EmailPasswordRecipe(RecipeModule):
     recipe_id = 'emailpassword'
     __instance = None
+    email_delivery: EmailDeliveryIngredient[TypeEmailPasswordEmailDeliveryInput]
 
     def __init__(self, recipe_id: str, app_info: AppInfo,
+                 ingredients: EmailPasswordIngredients,
                  sign_up_feature: Union[InputSignUpFeature, None] = None,
                  reset_password_using_token_feature: Union[InputResetPasswordUsingTokenFeature, None] = None,
                  email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
                  override: Union[InputOverrideConfig, None] = None,
-                 email_verification_recipe: Union[EmailVerificationRecipe, None] = None):
+                 email_verification_recipe: Union[EmailVerificationRecipe, None] = None,
+                 email_delivery: Union[EmailDeliveryConfig[TypeEmailPasswordEmailDeliveryInput], None] = None,
+                 ):
         super().__init__(recipe_id, app_info)
         self.config = validate_and_normalise_user_input(self, app_info, sign_up_feature,
                                                         reset_password_using_token_feature,
-                                                        email_verification_feature, override)
+                                                        email_verification_feature, override, email_delivery)
+        recipe_implementation = RecipeImplementation(Querier.get_instance(recipe_id))
+        self.recipe_implementation = recipe_implementation if self.config.override.functions is None else \
+            self.config.override.functions(recipe_implementation)
+
+        email_delivery_ingredient = ingredients.email_delivery
+        if email_delivery_ingredient is None:
+            self.email_delivery = EmailDeliveryIngredient(self.config.get_email_delivery_config(self.recipe_implementation))
+        else:
+            self.email_delivery = email_delivery_ingredient
+
         if email_verification_recipe is not None:
             self.email_verification_recipe = email_verification_recipe
         else:
+            ev_email_delivery_ingredient = cast(
+                EmailDeliveryIngredient[TypeEmailVerificationEmailDeliveryInput],
+                self.email_delivery
+            )
+
+            email_verification_ingredients = EmailVerificationIngredients(email_delivery=ev_email_delivery_ingredient)
             self.email_verification_recipe = EmailVerificationRecipe(recipe_id, app_info,
-                                                                     self.config.email_verification_feature)
-        recipe_implementation = RecipeImplementation(
-            Querier.get_instance(recipe_id))
-        self.recipe_implementation = recipe_implementation if self.config.override.functions is None else \
-            self.config.override.functions(recipe_implementation)
+                                                                     self.config.email_verification_feature,
+                                                                     ingredients=email_verification_ingredients)
+
         api_implementation = APIImplementation()
         self.api_implementation = api_implementation if self.config.override.apis is None else \
             self.config.override.apis(api_implementation)
@@ -99,7 +127,7 @@ class EmailPasswordRecipe(RecipeModule):
 
     async def handle_api_request(self, request_id: str, request: BaseRequest, path: NormalisedURLPath, method: str,
                                  response: BaseResponse):
-        api_options = APIOptions(request, response, self.recipe_id, self.config, self.recipe_implementation, self.email_verification_recipe.recipe_implementation)
+        api_options = APIOptions(request, response, self.recipe_id, self.config, self.recipe_implementation, self.email_verification_recipe.recipe_implementation, self.email_delivery)
         if request_id == SIGNUP:
             return await handle_sign_up_api(self.api_implementation,
                                             api_options)
@@ -132,10 +160,12 @@ class EmailPasswordRecipe(RecipeModule):
     def init(sign_up_feature: Union[InputSignUpFeature, None] = None,
              reset_password_using_token_feature: Union[InputResetPasswordUsingTokenFeature, None] = None,
              email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
-             override: Union[InputOverrideConfig, None] = None):
+             override: Union[InputOverrideConfig, None] = None,
+             email_delivery: Union[EmailDeliveryConfig[TypeEmailPasswordEmailDeliveryInput], None] = None):
         def func(app_info: AppInfo):
             if EmailPasswordRecipe.__instance is None:
-                EmailPasswordRecipe.__instance = EmailPasswordRecipe(EmailPasswordRecipe.recipe_id, app_info, sign_up_feature, reset_password_using_token_feature, email_verification_feature, override)
+                ingredients = EmailPasswordIngredients(None)
+                EmailPasswordRecipe.__instance = EmailPasswordRecipe(EmailPasswordRecipe.recipe_id, app_info, ingredients, sign_up_feature, reset_password_using_token_feature, email_verification_feature, override, email_delivery=email_delivery)
                 return EmailPasswordRecipe.__instance
             raise Exception(None, 'Emailpassword recipe has already been initialised. Please check your code for bugs.')
 
