@@ -11,19 +11,26 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Dict
 
-from httpx import AsyncClient
+from supertokens_python.ingredients.emaildelivery.types import (
+    EmailDeliveryConfig, EmailDeliveryConfigWithService)
+from supertokens_python.recipe.emailverification.emaildelivery.services.backward_compatibility import \
+    BackwardCompatibilityService
+from supertokens_python.recipe.emailverification.interfaces import \
+    TypeEmailVerificationEmailDeliveryInput
+from supertokens_python.utils import deprecated_warn
 
 if TYPE_CHECKING:
-    from supertokens_python.supertokens import AppInfo
-    from .types import User
-    from .interfaces import RecipeInterface, APIInterface
-    from typing import Callable, Union, Awaitable
+    from typing import Awaitable, Callable, Union
 
-from os import environ
+    from supertokens_python.supertokens import AppInfo
+
+    from .interfaces import APIInterface, RecipeInterface
+    from .types import User
 
 
 def default_get_email_verification_url(app_info: AppInfo) -> Callable[[User, Dict[str, Any]], Awaitable[str]]:
@@ -33,20 +40,8 @@ def default_get_email_verification_url(app_info: AppInfo) -> Callable[[User, Dic
     return func
 
 
-def default_create_and_send_custom_email(app_info: AppInfo) -> Callable[[User, str, Dict[str, Any]], Awaitable[None]]:
-    async def func(user: User, email_verification_url: str, _: Dict[str, Any]):
-        if ('SUPERTOKENS_ENV' in environ) and (
-                environ['SUPERTOKENS_ENV'] == 'testing'):
-            return
-        try:
-            async with AsyncClient() as client:
-                await client.post('https://api.supertokens.io/0/st/auth/email/verify', json={'email': user.email, 'appName': app_info.app_name, 'emailVerifyURL': email_verification_url}, headers={'api-version': '0'})  # type: ignore
-        except Exception:
-            pass
-    return func
-
-
 class OverrideConfig:
+
     def __init__(self, functions: Union[Callable[[RecipeInterface], RecipeInterface], None] = None,
                  apis: Union[Callable[[APIInterface], APIInterface], None] = None):
         self.functions = functions
@@ -57,39 +52,53 @@ class ParentRecipeEmailVerificationConfig:
     def __init__(self,
                  get_email_for_user_id: Callable[[str, Dict[str, Any]], Awaitable[str]],
                  override: Union[OverrideConfig, None] = None,
-                 get_email_verification_url: Union[Callable[[
-                     User, Dict[str, Any]], Awaitable[str]], None] = None,
-                 create_and_send_custom_email: Union[Callable[[
-                     User, str, Dict[str, Any]], Awaitable[None]], None] = None
+                 get_email_verification_url: Union[Callable[[User, Dict[str, Any]], Awaitable[str]], None] = None,
+                 create_and_send_custom_email: Union[Callable[[User, str, Dict[str, Any]], Awaitable[None]], None] = None,
+                 email_delivery: Union[EmailDeliveryConfig[TypeEmailVerificationEmailDeliveryInput], None] = None,
                  ):
         self.override = override
         self.get_email_verification_url = get_email_verification_url
-        self.create_and_send_custom_email = create_and_send_custom_email
         self.get_email_for_user_id = get_email_for_user_id
+        self.email_delivery = email_delivery
+        self.create_and_send_custom_email = create_and_send_custom_email
+
+        if create_and_send_custom_email:
+            # Note: This will appear twice because `InputEmailVerificationConfig` will also produce same warning.
+            deprecated_warn("create_and_send_custom_email is deprecated. Please use email delivery config instead")
 
 
 class EmailVerificationConfig:
     def __init__(self,
                  override: OverrideConfig,
                  get_email_verification_url: Callable[[User, Dict[str, Any]], Awaitable[str]],
-                 create_and_send_custom_email: Callable[[User, str, Dict[str, Any]], Awaitable[None]],
-                 get_email_for_user_id: Callable[[str, Dict[str, Any]], Awaitable[str]]
+                 get_email_for_user_id: Callable[[str, Dict[str, Any]], Awaitable[str]],
+                 get_email_delivery_config: Callable[[], EmailDeliveryConfigWithService[TypeEmailVerificationEmailDeliveryInput]],
                  ):
         self.get_email_for_user_id = get_email_for_user_id
         self.get_email_verification_url = get_email_verification_url
-        self.create_and_send_custom_email = create_and_send_custom_email
         self.override = override
+        self.get_email_delivery_config = get_email_delivery_config
 
 
 def validate_and_normalise_user_input(
-        app_info: AppInfo, config: ParentRecipeEmailVerificationConfig):
+        app_info: AppInfo, config: ParentRecipeEmailVerificationConfig) -> EmailVerificationConfig:
     if not isinstance(config, ParentRecipeEmailVerificationConfig):  # type: ignore
         raise ValueError('config must be an instance of ParentRecipeEmailVerificationConfig')
 
     get_email_verification_url = config.get_email_verification_url if config.get_email_verification_url is not None \
         else default_get_email_verification_url(app_info)
-    create_and_send_custom_email = config.create_and_send_custom_email if config.create_and_send_custom_email is not None \
-        else default_create_and_send_custom_email(app_info)
+
+    def get_email_delivery_config() -> EmailDeliveryConfigWithService[TypeEmailVerificationEmailDeliveryInput]:
+        email_service = config.email_delivery.service if config.email_delivery is not None else None
+        if email_service is None:
+            email_service = BackwardCompatibilityService(app_info, config.create_and_send_custom_email)
+
+        if config.email_delivery is not None and config.email_delivery.override is not None:
+            override = config.email_delivery.override
+        else:
+            override = None
+        return EmailDeliveryConfigWithService(email_service, override=override)
+
     override = config.override
 
     if override is not None and not isinstance(override, OverrideConfig):  # type: ignore
@@ -97,9 +106,10 @@ def validate_and_normalise_user_input(
 
     if override is None:
         override = OverrideConfig()
+
     return EmailVerificationConfig(
-        override=override,
-        get_email_for_user_id=config.get_email_for_user_id,
-        create_and_send_custom_email=create_and_send_custom_email,
-        get_email_verification_url=get_email_verification_url
+        override,
+        get_email_verification_url,
+        config.get_email_for_user_id,
+        get_email_delivery_config,
     )
