@@ -21,12 +21,8 @@ from supertokens_python.recipe.jwt.interfaces import (CreateJwtOkResult,
 
 
 def create_jwt(payload: Union[None, Dict[str, Any]] = None, validity_seconds: Union[None, int] = None, user_context: Union[Dict[str, Any], None] = None) -> Union[CreateJwtOkResult, CreateJwtResultUnsupportedAlgorithm]:
-    if user_context is None:
-        user_context = {}
     return sync(asyncio.create_jwt(payload, validity_seconds, user_context))
 
 
 def get_jwks(user_context: Union[Dict[str, Any], None] = None) -> GetJWKSResult:
-    if user_context is None:
-        user_context = {}
     return sync(asyncio.get_jwks(user_context))
