@@ -13,23 +13,23 @@
 # under the License.
 from typing import Any, Dict, Union
 
+from supertokens_python.logger import log_debug_message
 from supertokens_python.recipe.passwordless.interfaces import (
     APIInterface, APIOptions, ConsumeCodeExpiredUserInputCodeError,
     ConsumeCodeIncorrectUserInputCodeError,
-    ConsumeCodePostExpiredUserInputCodeError,
-    ConsumeCodePostIncorrectUserInputCodeError,
-    ConsumeCodePostOkResult, ConsumeCodePostGeneralError,
+    ConsumeCodePostExpiredUserInputCodeError, ConsumeCodePostGeneralError,
+    ConsumeCodePostIncorrectUserInputCodeError, ConsumeCodePostOkResult,
     ConsumeCodePostRestartFlowError, ConsumeCodeRestartFlowError,
-    CreateCodeOkResult, CreateCodePostGeneralError,
-    CreateCodePostOkResult,
+    CreateCodePostGeneralError, CreateCodePostOkResult,
+    CreateNewCodeForDeviceOkResult,
     CreateNewCodeForDeviceUserInputCodeAlreadyUsedError,
     EmailExistsGetOkResult, PhoneNumberExistsGetOkResult,
     ResendCodePostGeneralError, ResendCodePostOkResult,
-    ResendCodePostRestartFlowError)
+    ResendCodePostRestartFlowError, TypePasswordlessEmailDeliveryInput)
+from supertokens_python.recipe.passwordless.types import \
+    TypePasswordlessSmsDeliveryInput
 from supertokens_python.recipe.passwordless.utils import (
-    ContactEmailOnlyConfig, ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig,
-    CreateAndSendCustomEmailParameters,
-    CreateAndSendCustomTextMessageParameters)
+    ContactEmailOnlyConfig, ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)
 from supertokens_python.recipe.session.asyncio import create_new_session
 
 from ..utils import PhoneOrEmailInput
@@ -60,23 +60,28 @@ class APIImplementation(APIInterface):
                     (isinstance(api_options.config.contact_config, ContactEmailOrPhoneConfig) and email is not None):
                 if email is None:
                     raise Exception("Should never come here")
-                await api_options.config.contact_config.create_and_send_custom_email(CreateAndSendCustomEmailParameters(
+
+                log_debug_message("Sending passwordless login email to %s", email)
+                passwordless_email_delivery_input = TypePasswordlessEmailDeliveryInput(
                     email=email,
                     user_input_code=user_input_code,
                     url_with_link_code=magic_link,
                     code_life_time=response.code_life_time,
                     pre_auth_session_id=response.pre_auth_session_id
-                ), user_context)
+                )
+                await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
             elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
                 if phone_number is None:
                     raise Exception("Should never come here")
-                await api_options.config.contact_config.create_and_send_custom_text_message(CreateAndSendCustomTextMessageParameters(
+                log_debug_message("Sending passwordless login SMS to %s", phone_number)
+                sms_input = TypePasswordlessSmsDeliveryInput(
                     phone_number=phone_number,
                     user_input_code=user_input_code,
                     url_with_link_code=magic_link,
                     code_life_time=response.code_life_time,
-                    pre_auth_session_id=response.pre_auth_session_id
-                ), user_context)
+                    pre_auth_session_id=response.pre_auth_session_id,
+                )
+                await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
         except Exception as e:
             return CreateCodePostGeneralError(str(e))
         return CreateCodePostOkResult(response.device_id, response.pre_auth_session_id, flow_type)
@@ -112,7 +117,7 @@ class APIImplementation(APIInterface):
                         'Failed to generate a one time code. Please try again')
                 continue
 
-            if isinstance(response, CreateCodeOkResult):
+            if isinstance(response, CreateNewCodeForDeviceOkResult):
                 magic_link = None
                 user_input_code = None
                 flow_type = api_options.config.flow_type
@@ -127,28 +132,34 @@ class APIImplementation(APIInterface):
                     if isinstance(api_options.config.contact_config, ContactEmailOnlyConfig) or \
                             (isinstance(api_options.config.contact_config,
                                         ContactEmailOrPhoneConfig) and device_info.email is not None):
-                        if device_info.email is None or response.code_life_time is None or response.pre_auth_session_id is None:
+                        if device_info.email is None:
                             raise Exception("Should never come here")
-                        await api_options.config.contact_config.create_and_send_custom_email(CreateAndSendCustomEmailParameters(
+
+                        log_debug_message("Sending passwordless login email to %s", device_info.email)
+                        passwordless_email_delivery_input = TypePasswordlessEmailDeliveryInput(
                             email=device_info.email,
                             user_input_code=user_input_code,
                             url_with_link_code=magic_link,
                             code_life_time=response.code_life_time,
                             pre_auth_session_id=response.pre_auth_session_id
-                        ), user_context)
+                        )
+                        await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
                     elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
-                        if device_info.phone_number is None or response.code_life_time is None or response.pre_auth_session_id is None:
+                        if device_info.phone_number is None:
                             raise Exception("Should never come here")
-                        await api_options.config.contact_config.create_and_send_custom_text_message(CreateAndSendCustomTextMessageParameters(
+                        log_debug_message("Sending passwordless login SMS to %s", device_info.phone_number)
+                        sms_input = TypePasswordlessSmsDeliveryInput(
                             phone_number=device_info.phone_number,
                             user_input_code=user_input_code,
                             url_with_link_code=magic_link,
                             code_life_time=response.code_life_time,
-                            pre_auth_session_id=response.pre_auth_session_id
-                        ), user_context)
+                            pre_auth_session_id=response.pre_auth_session_id,
+                        )
+                        await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
                 except Exception as e:
                     return ResendCodePostGeneralError(str(e))
-            return ResendCodePostOkResult()
+                return ResendCodePostOkResult()
+            return ResendCodePostRestartFlowError()
 
     async def consume_code_post(self,
                                 pre_auth_session_id: str,
