@@ -16,7 +16,14 @@ from __future__ import annotations
 from os import environ
 from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, List, Union
 
+from supertokens_python.ingredients.emaildelivery import \
+    EmailDeliveryIngredient
+from supertokens_python.ingredients.emaildelivery.types import \
+    EmailDeliveryConfig
+from supertokens_python.ingredients.smsdelivery import SMSDeliveryIngredient
 from supertokens_python.querier import Querier
+from supertokens_python.recipe.passwordless.types import (
+    PasswordlessIngredients, TypePasswordlessSmsDeliveryInput)
 from typing_extensions import Literal
 
 from .api import (consume_code, create_code, email_exists, phone_number_exists,
@@ -26,7 +33,8 @@ from .constants import (CONSUME_CODE_API, CREATE_CODE_API,
                         DOES_EMAIL_EXIST_API, DOES_PHONE_NUMBER_EXIST_API,
                         RESEND_CODE_API)
 from .exceptions import SuperTokensPasswordlessError
-from .interfaces import APIOptions, ConsumeCodeOkResult, RecipeInterface
+from .interfaces import (APIOptions, ConsumeCodeOkResult, RecipeInterface,
+                         TypePasswordlessEmailDeliveryInput)
 from .recipe_implementation import RecipeImplementation
 from .utils import (ContactConfig, OverrideConfig, PhoneOrEmailInput,
                     validate_and_normalise_user_input)
@@ -38,6 +46,7 @@ if TYPE_CHECKING:
 
 from supertokens_python.exceptions import (SuperTokensError,
                                            raise_general_exception)
+from supertokens_python.ingredients.smsdelivery.types import SMSDeliveryConfig
 from supertokens_python.normalised_url_path import NormalisedURLPath
 from supertokens_python.recipe_module import APIHandled, RecipeModule
 
@@ -45,25 +54,40 @@ from supertokens_python.recipe_module import APIHandled, RecipeModule
 class PasswordlessRecipe(RecipeModule):
     recipe_id = 'passwordless'
     __instance = None
+    email_delivery: EmailDeliveryIngredient[TypePasswordlessEmailDeliveryInput]
+    sms_delivery: SMSDeliveryIngredient[TypePasswordlessSmsDeliveryInput]
 
     def __init__(self, recipe_id: str, app_info: AppInfo, contact_config: ContactConfig,
                  flow_type: Literal['USER_INPUT_CODE', 'MAGIC_LINK', 'USER_INPUT_CODE_AND_MAGIC_LINK'],
+                 ingredients: PasswordlessIngredients,
                  override: Union[OverrideConfig, None] = None,
                  get_link_domain_and_path: Union[Callable[[
                      PhoneOrEmailInput, Dict[str, Any]], Awaitable[str]], None] = None,
-                 get_custom_user_input_code: Union[Callable[[Dict[str, Any]], Awaitable[str]], None] = None):
+                 get_custom_user_input_code: Union[Callable[[Dict[str, Any]], Awaitable[str]], None] = None,
+                 email_delivery: Union[EmailDeliveryConfig[TypePasswordlessEmailDeliveryInput], None] = None,
+                 sms_delivery: Union[SMSDeliveryConfig[TypePasswordlessSmsDeliveryInput], None] = None,
+                 ):
         super().__init__(recipe_id, app_info)
         self.config = validate_and_normalise_user_input(app_info, contact_config, flow_type, override,
-                                                        get_link_domain_and_path, get_custom_user_input_code)
+                                                        get_link_domain_and_path, get_custom_user_input_code, email_delivery, sms_delivery)
 
-        recipe_implementation = RecipeImplementation(
-            Querier.get_instance(recipe_id))
+        recipe_implementation = RecipeImplementation(Querier.get_instance(recipe_id))
         self.recipe_implementation: RecipeInterface = recipe_implementation if self.config.override.functions is None else \
             self.config.override.functions(recipe_implementation)
+
         api_implementation = APIImplementation()
         self.api_implementation = api_implementation if self.config.override.apis is None else \
             self.config.override.apis(api_implementation)
 
+        email_delivery_ingredient = ingredients.email_delivery
+        if email_delivery_ingredient is None:
+            self.email_delivery = EmailDeliveryIngredient(self.config.get_email_delivery_config())
+        else:
+            self.email_delivery = email_delivery_ingredient
+
+        sms_delivery_ingredient = ingredients.sms_delivery
+        self.sms_delivery = SMSDeliveryIngredient(self.config.get_sms_delivery_config()) if sms_delivery_ingredient is None else sms_delivery_ingredient
+
     def get_apis_handled(self) -> List[APIHandled]:
         return [
             APIHandled(method='post', path_without_api_base_path=NormalisedURLPath(CONSUME_CODE_API),
@@ -90,7 +114,10 @@ class PasswordlessRecipe(RecipeModule):
             response,
             self.get_recipe_id(),
             self.config,
-            self.recipe_implementation)
+            self.recipe_implementation,
+            self.email_delivery,
+            self.sms_delivery
+        )
         if request_id == CONSUME_CODE_API:
             return await consume_code(self.api_implementation, options)
         if request_id == CREATE_CODE_API:
@@ -118,14 +145,23 @@ class PasswordlessRecipe(RecipeModule):
              override: Union[OverrideConfig, None] = None,
              get_link_domain_and_path: Union[Callable[[
                  PhoneOrEmailInput, Dict[str, Any]], Awaitable[str]], None] = None,
-             get_custom_user_input_code: Union[Callable[[Dict[str, Any]], Awaitable[str]], None] = None):
+             get_custom_user_input_code: Union[Callable[[Dict[str, Any]], Awaitable[str]], None] = None,
+             email_delivery: Union[EmailDeliveryConfig[TypePasswordlessEmailDeliveryInput], None] = None,
+             sms_delivery: Union[SMSDeliveryConfig[TypePasswordlessSmsDeliveryInput], None] = None,
+             ):
         def func(app_info: AppInfo):
             if PasswordlessRecipe.__instance is None:
+                ingredients = PasswordlessIngredients(None, None)
                 PasswordlessRecipe.__instance = PasswordlessRecipe(
                     PasswordlessRecipe.recipe_id,
                     app_info,
-                    contact_config, flow_type, override,
-                    get_link_domain_and_path, get_custom_user_input_code)
+                    contact_config, flow_type,
+                    ingredients,
+                    override,
+                    get_link_domain_and_path, get_custom_user_input_code,
+                    email_delivery,
+                    sms_delivery,
+                )
                 return PasswordlessRecipe.__instance
             raise_general_exception('Passwordless recipe has already been initialised. Please check '
                                     'your code for bugs.')
