@@ -29,10 +29,11 @@ class Google(Provider):
                  authorisation_redirect: Union[None, Dict[str, Union[str, Callable[[
                      BaseRequest], str]]]] = None,
                  is_default: bool = False):
-        super().__init__('google', client_id, is_default)
+        super().__init__('google', is_default)
         default_scopes = ['https://www.googleapis.com/auth/userinfo.email']
         if scope is None:
             scope = default_scopes
+        self.client_id = client_id
         self.client_secret = client_secret
         self.scopes = list(set(scope))
         self.access_token_api_url = 'https://accounts.google.com/o/oauth2/token'
@@ -85,3 +86,6 @@ class Google(Provider):
 
     def get_redirect_uri(self, user_context: Dict[str, Any]) -> Union[None, str]:
         return None
+
+    def get_client_id(self, user_context: Dict[str, Any]) -> str:
+        return self.client_id
