@@ -14,12 +14,25 @@
 from __future__ import annotations
 
 from os import environ
-from typing import TYPE_CHECKING, Any, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Union, cast
 
 from supertokens_python.framework.response import BaseResponse
+from supertokens_python.ingredients.emaildelivery.types import \
+    EmailDeliveryConfig
 from supertokens_python.normalised_url_path import NormalisedURLPath
 from supertokens_python.querier import Querier
+from supertokens_python.recipe.emailpassword.types import \
+    EmailPasswordIngredients
+from supertokens_python.recipe.emailverification.interfaces import \
+    TypeEmailVerificationEmailDeliveryInput
+from supertokens_python.recipe.emailverification.types import \
+    EmailVerificationIngredients
 from supertokens_python.recipe.thirdparty.provider import Provider
+from supertokens_python.recipe.thirdparty.types import (
+    ThirdPartyIngredients, TypeThirdPartyEmailDeliveryInput)
+from supertokens_python.recipe.thirdpartyemailpassword.types import (
+    ThirdPartyEmailPasswordIngredients,
+    TypeThirdPartyEmailPasswordEmailDeliveryInput)
 from supertokens_python.recipe_module import APIHandled, RecipeModule
 
 from ..emailpassword.utils import (InputResetPasswordUsingTokenFeature,
@@ -41,6 +54,8 @@ if TYPE_CHECKING:
     from supertokens_python.supertokens import AppInfo
 
 from supertokens_python.exceptions import SuperTokensError
+from supertokens_python.ingredients.emaildelivery import \
+    EmailDeliveryIngredient
 from supertokens_python.recipe.emailpassword import EmailPasswordRecipe
 from supertokens_python.recipe.emailpassword.utils import \
     InputOverrideConfig as EPOverrideConfig
@@ -65,24 +80,29 @@ from .utils import InputOverrideConfig, validate_and_normalise_user_input
 class ThirdPartyEmailPasswordRecipe(RecipeModule):
     recipe_id = 'thirdpartyemailpassword'
     __instance = None
+    email_delivery: EmailDeliveryIngredient[TypeThirdPartyEmailPasswordEmailDeliveryInput]
 
     def __init__(self, recipe_id: str, app_info: AppInfo,
+                 ingredients: ThirdPartyEmailPasswordIngredients,
                  sign_up_feature: Union[InputSignUpFeature, None] = None,
                  reset_password_using_token_feature: Union[InputResetPasswordUsingTokenFeature, None] = None,
                  email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
                  override: Union[InputOverrideConfig, None] = None,
                  providers: Union[List[Provider], None] = None,
                  email_verification_recipe: Union[EmailVerificationRecipe, None] = None,
-                 email_password_recipe: Union[EmailPasswordRecipe,
-                                              None] = None,
-                 third_party_recipe: Union[ThirdPartyRecipe, None] = None):
+                 email_password_recipe: Union[EmailPasswordRecipe, None] = None,
+                 third_party_recipe: Union[ThirdPartyRecipe, None] = None,
+                 email_delivery: Union[EmailDeliveryConfig[TypeThirdPartyEmailPasswordEmailDeliveryInput], None] = None,
+                 ):
         super().__init__(recipe_id, app_info)
         self.config = validate_and_normalise_user_input(self,
                                                         sign_up_feature,
                                                         reset_password_using_token_feature,
                                                         email_verification_feature,
                                                         override,
-                                                        providers)
+                                                        providers,
+                                                        email_delivery,
+                                                        )
 
         recipe_implementation = RecipeImplementation(Querier.get_instance(EmailPasswordRecipe.recipe_id),
                                                      Querier.get_instance(ThirdPartyRecipe.recipe_id))
@@ -92,23 +112,39 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         self.api_implementation: APIInterface = api_implementation if self.config.override.apis is None else \
             self.config.override.apis(api_implementation)
 
+        ep_recipe_implementation = EmailPasswordRecipeImplementation(self.recipe_implementation)
+
+        email_delivery_ingredient = ingredients.email_delivery
+        if email_delivery_ingredient is None:
+            self.email_delivery = EmailDeliveryIngredient(
+                self.config.get_email_delivery_config(self.recipe_implementation, ep_recipe_implementation)
+            )
+        else:
+            self.email_delivery = email_delivery_ingredient
+
         if email_verification_recipe is not None:
             self.email_verification_recipe = email_verification_recipe
         else:
+            ev_email_delivery_ingredient = cast(
+                EmailDeliveryIngredient[TypeEmailVerificationEmailDeliveryInput], self.email_delivery
+            )
+            ev_ingredients = EmailVerificationIngredients(ev_email_delivery_ingredient)
             self.email_verification_recipe = EmailVerificationRecipe(recipe_id, app_info,
-                                                                     self.config.email_verification_feature)
-
-        def func_override_email_password(_: EmailPasswordRecipeInterface) -> EmailPasswordRecipeInterface:
-            return EmailPasswordRecipeImplementation(
-                self.recipe_implementation)
-
-        def apis_override_email_password(_: EmailPasswordAPIInterface) -> EmailPasswordAPIInterface:
-            return get_email_password_interface_impl(self.api_implementation)
+                                                                     self.config.email_verification_feature, ev_ingredients)
 
         if email_password_recipe is not None:
             self.email_password_recipe = email_password_recipe
         else:
+            def func_override_email_password(_: EmailPasswordRecipeInterface):
+                return ep_recipe_implementation
+
+            def apis_override_email_password(_: EmailPasswordAPIInterface):
+                return get_email_password_interface_impl(self.api_implementation)
+
+            ingredient = self.email_delivery
+            ep_ingredients = EmailPasswordIngredients(ingredient)
             self.email_password_recipe = EmailPasswordRecipe(recipe_id, app_info,
+                                                             ep_ingredients,
                                                              self.config.sign_up_feature,
                                                              self.config.reset_password_using_token_feature,
                                                              None,
@@ -116,23 +152,27 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                                                                  func_override_email_password,
                                                                  apis_override_email_password
                                                              ),
-                                                             self.email_verification_recipe)
-
-        def func_override_third_party(_: ThirdPartyRecipeInterface) -> ThirdPartyRecipeInterface:
-            return ThirdPartyRecipeImplementation(self.recipe_implementation)
-
-        def apis_override_third_party(_: ThirdPartyAPIInterface) -> ThirdPartyAPIInterface:
-            return get_third_party_interface_impl(self.api_implementation)
+                                                             self.email_verification_recipe,
+                                                             )
 
         if third_party_recipe is not None:
             self.third_party_recipe: Union[ThirdPartyRecipe, None] = third_party_recipe
         else:
+            def func_override_third_party(_: ThirdPartyRecipeInterface) -> ThirdPartyRecipeInterface:
+                return ThirdPartyRecipeImplementation(self.recipe_implementation)
+
+            def apis_override_third_party(_: ThirdPartyAPIInterface) -> ThirdPartyAPIInterface:
+                return get_third_party_interface_impl(self.api_implementation)
+
             self.third_party_recipe: Union[ThirdPartyRecipe, None] = None
+            ingredient = cast(EmailDeliveryIngredient[TypeThirdPartyEmailDeliveryInput], self.email_delivery)
+            tp_ingredients = ThirdPartyIngredients(ingredient)
             if len(self.config.providers) != 0:
                 self.third_party_recipe = ThirdPartyRecipe(
                     recipe_id,
                     app_info,
                     SignInAndUpFeature(self.config.providers),
+                    tp_ingredients,
                     None,
                     TPOverrideConfig(
                         func_override_third_party,
@@ -201,15 +241,21 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
              reset_password_using_token_feature: Union[InputResetPasswordUsingTokenFeature, None] = None,
              email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
              override: Union[InputOverrideConfig, None] = None,
-             providers: Union[List[Provider], None] = None):
+             providers: Union[List[Provider], None] = None,
+             email_delivery: Union[EmailDeliveryConfig[TypeThirdPartyEmailPasswordEmailDeliveryInput], None] = None
+             ):
         def func(app_info: AppInfo):
             if ThirdPartyEmailPasswordRecipe.__instance is None:
+                ingredients = ThirdPartyEmailPasswordIngredients(None)
                 ThirdPartyEmailPasswordRecipe.__instance = ThirdPartyEmailPasswordRecipe(
-                    ThirdPartyEmailPasswordRecipe.recipe_id, app_info, sign_up_feature,
+                    ThirdPartyEmailPasswordRecipe.recipe_id, app_info, ingredients,
+                    sign_up_feature,
                     reset_password_using_token_feature,
                     email_verification_feature,
                     override,
-                    providers)
+                    providers,
+                    email_delivery=email_delivery
+                )
                 return ThirdPartyEmailPasswordRecipe.__instance
             raise Exception(None, 'ThirdPartyEmailPassword recipe has already been initialised. Please check your code for bugs.')
 
